#!/usr/bin/python

import os
import glob

from config import PREFIX
from run import run
from version import LIBXMLBIRD_SO_VERSION
from pkgconfig import generate_pkg_config_file

run ("mkdir -p build/bin");

run ("valac --ccode --pkg posix --library libxmlbird --vapi=xmlbird.vapi "
     + "--directory=./build -H ./build/xmlbird.h " + " ".join(sorted(glob.glob('libxmlbird/*.vala'))))

run ("""gcc -fPIC -c \
     $(pkg-config --cflags glib-2.0) \
     $(pkg-config --cflags gobject-2.0) \
     build/libxmlbird/*.c""");

run ("mv *.o build/libxmlbird/");

run ("""gcc -shared \
     -Wl,-soname,""" + "libxmlbird.so." + LIBXMLBIRD_SO_VERSION + "\
     build/libxmlbird/*.o \
     $(pkg-config --libs glib-2.0) \
     $(pkg-config --libs gobject-2.0) \
     -o build/bin/libxmlbird.so.""" + LIBXMLBIRD_SO_VERSION);

if os.path.islink('build/bin/libxmlbird.so'):
    run("unlink build/bin/libxmlbird.so")
    
run ("cd build/bin/ && \
     ln -s libxmlbird.so.""" + LIBXMLBIRD_SO_VERSION + " libxmlbird.so");
	
generate_pkg_config_file()



#!/usr/bin/python3

import dodo
from sys import platform

from scripts.builder import process_tasks
from scripts import config
from scripts import version
from scripts import tests

if platform == 'msys':
	process_tasks(dodo.make_libxmlbird('libxmlbird.dll'))
elif platform == 'darwin':
	lib = "libxmlbird-" + str(version.LIBXMLBIRD_SO_VERSION_MAJOR) + '.dylib'
	process_tasks(dodo.make_libxmlbird(lib))
elif "openbsd" in platform:
	process_tasks(dodo.make_libxmlbird('libxmlbird.so.${LIBxmlbird_VERSION}'))
else:
	process_tasks(dodo.make_libxmlbird('libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION))
	tests.build_tests();

dodo.make_libxmlbird_pkgconfig ()

print('Done')



#!/usr/bin/python3
import subprocess
from scripts.config import (PREFIX, VALAC)
from scripts.run import run
from scripts.version import LIBXMLBIRD_SO_VERSION

def read_elements(file):
    tests = []
    f = open(file)
    line = f.readline().strip ()
    while line:
        if not line == "":
            tests += [line]
        line = f.readline().strip ()
        
    return tests

def get_benchmarks():
    return read_elements("tests/benchmarks.txt")

def get_tests():
    return read_elements("tests/tests.txt")

def all_tests():
    tests = get_benchmarks()
    tests += get_tests()
    return tests

def build_tests():
    tests = all_tests() + ["fuzz"]
    run ("mkdir -p build/bin");
    run ("mkdir -p build/tests");

    for test in tests:
        run (VALAC + " --ccode --pkg=posix --pkg=xmlbird --vapidir=./build "
             + "--directory=./build tests/" + test + ".vala tests/Test.vala");

        run ("""gcc -fPIC -c \
			-I ./build/xmlbird \
             $(pkg-config --cflags glib-2.0) \
             $(pkg-config --cflags gobject-2.0) \
             -I ./build -L./build/bin -lxmlbird \
             build/tests/""" + test + """.c \
             build/tests/Test.c""");

        run ("mv *.o build/tests/");

        run ("""gcc build/tests/""" + test + """.o build/tests/Test.o \
             $(pkg-config --libs glib-2.0) \
             $(pkg-config --libs gobject-2.0) \
             -L./build/bin -lxmlbird \
             -o ./build/bin/""" + test);




#!/usr/bin/python3
"""
Copyright (C) 2013 2014 2015 Johan Mattsson

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import os
import subprocess
import glob
import platform
import sys
from optparse import OptionParser
from scripts import config
from scripts import version
from scripts.run import run

def getDest (file, dir):
	f = dest + prefix + dir + '/'
	s = file.rfind ('/')
	if s > -1:
		f += file[s + 1:]
	else:
		f += file
	return f

def getDestRoot (file, dir):
	f = dest + dir + '/'
	s = file.rfind ('/')
	if s > -1:
		f += file[s + 1:]
	else:
		f += file
	return f

def install (file, dir, mode):
	f = getDest (file, dir)
	print ("install: " + f)
	run ('install -d ' + dest + prefix + dir)
	run ('install -m ' + str(mode) + ' ' + file + ' ' + dest + prefix + dir + '/')

def install_root (file, dir, mode):
	f = getDestRoot (file, dir)
	print ("install: " + f)
	run ('install -d ' + dest + dir)
	run ('install -m ' + str(mode) + ' ' + file + ' ' + dest + dir + '/')

def link (dir, file, linkname):
	f = getDest (linkname, dir)
	print ("install link: " + f)
	run ('cd ' + dest + prefix + dir + ' && ln -sf ' + file + ' ' + linkname)

parser = OptionParser()
parser.add_option ("-d", "--dest", dest="dest", help="install to this directory", metavar="DEST")

(options, args) = parser.parse_args()

if not options.dest:
	options.dest = ""

prefix = config.PREFIX
dest = options.dest

libdir = config.LIBDIR
if "openbsd" in sys.platform:
	install ('build/bin/libxmlbird.so.' + '${LIBxmlbird_VERSION}', libdir, 755)
elif os.path.isfile ('build/bin/libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION):
	install ('build/bin/libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION, libdir, 755)
	link (libdir, 'libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION, ' libxmlbird.so')
elif os.path.isfile ('build/libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION):
	install ('build/libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION, libdir, 755)
	link (libdir, 'libxmlbird.so.' + version.LIBXMLBIRD_SO_VERSION, ' libxmlbird.so')
elif os.path.isfile ('build/bin/libxmlbird-' + version.LIBXMLBIRD_SO_VERSION_MAJOR + '.dylib'):
	install ('build/bin/libxmlbird-' + version.LIBXMLBIRD_SO_VERSION_MAJOR + '.dylib', libdir, 755)
	link (libdir, 'libxmlbird-' + version.LIBXMLBIRD_SO_VERSION_MAJOR + '.dylib', ' libxmlbird.dylib')
else:
   print("Can't find libxmlbird, so-version: " + str(version.LIBXMLBIRD_SO_VERSION))
   exit (1)

install ('build/xmlbird/xmlbird.h', '/include', 644)
install ('build/xmlbird.vapi', '/share/vala/vapi', 644)
install ('build/xmlbird.pc', libdir + '/pkgconfig', 644)
